==> kara-uc-1.1.16.tgz: package/src/kara-uc/components/UCFavorite/All/newsComponent/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import DataUtil from '../../../../util/dateTime'
import Modal from 'react-modal-plugin'
import tost,{errorTost} from "kara-module-tost"
import 'kara-module-tost/lib/index.css'
import Forward from 'kara-module-forward'
import 'kara-module-forward/lib/index.css'

@observer
class NewsComponent extends Component{
  constructor(props) {
    super(props)
    this.state = {
      showmodal: false,
      shareParams: {}
    }
  }
  cancelFavorite = (id,type) => {
    this.props.httpAgent.post(`/webapi/commonFavorite/set`,{id: id, 
      type: type, 
    }).then(
      res => {
        if(res && res.resultCode && res.resultCode === '000000') {
          tost({type:'success',msg:'取消收藏成功',time:4}) 
          this.props.cancelCmsFavorite(id, type, this.props.fromPage)
        }
        else {
          tost({type:'error',msg:'取消收藏失败',time:4}) 
        }
      }
    )
  }
  modalForwardShow = (info) => {
    this.setState({showForwardModal: true})
    this.setState({shareParams: {
      title: info.title,
      description: info.description,
      thumbUrl: info.textImages[0],
      url: info.s3Url
    }})
  }
  modalForwardHide = () => {
    this.setState({showForwardModal: false})
  }
  imgError = (e) => {
    e.target.style.display = 'none'
  }
  render(){
    const {lang, fileAttr} = this.props
    const {sesFavoriteCmsInfo:{s3Url,title,textImages,categoryName,commentCount,created,articleId}} = fileAttr
    return (<div className={`s-b-secondary ${css.newsContainer}`}>
    <div className={css.newsItem}>
      <a className={css.title} href={s3Url} target="_blank">
      {title}
      </a>
      <a className={`clearfix ${css.thumb}`} href={s3Url} target="_blank">
        {
          textImages.map((j,key) => {
            return <img src={j} key={key} alt='' onError={this.imgError} />
          })
        }
      </a>
      <div className={`s-hint ${css.handle}`}>
        <span>{categoryName}</span>
        <span>{commentCount}&nbsp;评论</span>
        <span>{DataUtil.DateShow(created)}</span>
        <span className={css.hoverShow} onClick={()=>{this.modalForwardShow(fileAttr.sesFavoriteCmsInfo)}}><i className='kuc-iconfont kuc-forward'></i>&nbsp;{lang.forward}</span>
        <span className={css.hoverShow} onClick={()=>{this.cancelFavorite(articleId,fileAttr.favoriteType)}}>
          <i className='kuc-iconfont kuc-favorite s-primary'></i>&nbsp;{lang.cancelCollect}
        </span>
      </div>
    </div>
    <Modal show={this.state.showForwardModal} onMask={this.modalForwardHide}>
      <Forward httpAgent={this.props.httpAgent} 
        shareParams={this.state.shareParams} 
      type='quan' modalHidden={this.modalForwardHide}  />
    </Modal>
  </div>)
  }
}

export default NewsComponent

==> kara-uc-1.1.29.tgz: package/src/kara-uc/components/UCFavorite/All/newsComponent/index.js <==
import React, {Component} from 'react'
import css from './index.scss'
import DataUtil from '../../../../util/dateTime'
import Modal from 'react-modal-plugin'
import tost,{errorTost} from "kara-module-tost"
import 'kara-module-tost/lib/index.css'

class NewsComponent extends Component{
  constructor(props) {
    super(props)
    this.state = {
      showmodal: false,
      shareParams: {},
        height: 'auto'
    }
      this.container = React.createRef()
  }

    componentDidMount() {
        if (this.state.height === 'auto' && this.container.current) {
            this.setState({ height: this.container.current.offsetHeight})
        }
    }
  cancelFavorite = (id,type) => {
    this.props.httpAgent.post(`/webapi/commonFavorite/set`,{id: id, 
      type: type, 
    }).then(
      res => {
        if(res && res.resultCode && res.resultCode === '000000') {
          tost({type:'success',msg:'取消收藏成功',time:4}) 
          this.props.cancelCmsFavorite(id, type, this.props.fromPage)
        }
        else {
          tost({type:'error',msg:'取消收藏失败',time:4}) 
        }
      }
    )
  }
  modalForwardShow = (info) => {
    this.setState({showForwardModal: true})
    this.setState({shareParams: {
      title: info.title,
      description: info.description,
      thumbUrl: info.textImages[0],
      url: info.s3Url
    }})
  }
  modalForwardHide = () => {
    this.setState({showForwardModal: false})
  }
  imgError = (e) => {
    e.target.style.display = 'none'
  }
  render(){
    const {lang, fileAttr, karaui:{Forward}} = this.props
    const {sesFavoriteCmsInfo:{s3Url,title,textImages,categoryName,commentCount,created,articleId}} = fileAttr
    return (<div ref={this.container} className={`s-b-secondary ${css.newsContainer}`} style={{height: fileAttr.canceled ? 0 : this.state.height}}>
    <div className={css.newsItem}>
      <a className={css.title} href={s3Url} target="_blank">
      {title}
      </a>
      <a className={`clearfix ${css.thumb}`} href={s3Url} target="_blank">
        {
          textImages.map((j,key) => {
            return <img src={j} key={key} alt='' onError={this.imgError} />
          })
        }
      </a>
      <div className={`s-hint ${css.handle}`}>
        <span>{categoryName}</span>
        <span>{commentCount}&nbsp;评论</span>
        <span>{DataUtil.DateShow(created)}</span>
        <span className={css.hoverShow} onClick={()=>{this.modalForwardShow(fileAttr.sesFavoriteCmsInfo)}}><i className='kuc-iconfont kuc-forward'></i>&nbsp;{lang.forward}</span>
        <span className={css.hoverShow} onClick={()=>{this.cancelFavorite(articleId,fileAttr.favoriteType)}}>
          <i className='kuc-iconfont kuc-favorite s-primary'></i>&nbsp;{lang.cancelCollect}
        </span>
      </div>
    </div>
    <Modal show={this.state.showForwardModal} onMask={this.modalForwardHide}>
      <Forward httpAgent={this.props.httpAgent} 
        shareParams={this.state.shareParams} 
      type='quan' modalHidden={this.modalForwardHide}  />
    </Modal>
  </div>)
  }
}

export default NewsComponent
